"""
Allows for tracking current stage of in-progress DAGs.
"""
import argparse
from argparse import ArgumentParser
from http import HTTPStatus

import requests
from pycapo import CapoConfig
from requests import Response


def parser() -> ArgumentParser:
    """
    Initialize argument parser for CLI

    :return: ArgumentParser
    """
    parser = ArgumentParser(
        description="Update Stage allows for tracking the current stage of in-progress workflows",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    parser.add_argument(
        "request_id",
        type=int,
        action="store",
        help="the workflow request ID of the running workflow",
    )

    return parser


def send_update(message: dict):
    """
    Make use of HTCondor Chirp Protocol to update stage

    :param message: the dict containing message parameters
    """

    pass


def build_message(args: argparse.Namespace) -> dict:
    """
    Build message dict

    :param args:
    :return:
    """
    message = {}

    if args.casa:
        message["current_stage"] = "CASA_ENVOY"
        message["previous_stage"] = "FETCH"
    if args.auto_qa:
        message["current_stage"] = "AUTO_QA"
        message["previous_stage"] = "CASA_ENVOY"
    if args.convey:
        message["current_stage"] = "CONVEY"
        message["previous_stage"] = "CASA_ENVOY"

    if args.vlass:
        message["is_vlass"] = True
    else:
        message["is_vlass"] = False

    return message


def main():
    """
    Run update

    :return:
    """

    args = parser().parse_args()

    message = build_message(args)
    send_update(message)
